#
# spec file for package hamlib
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   4
Name:           hamlib
Version:        4.6.2
Release:        1.2
Summary:        Run-time library to control radio transcievers and receivers
License:        LGPL-2.1-only
Group:          Productivity/Hamradio/Other
URL:            https://hamlib.github.io/
Source:         https://github.com/Hamlib/Hamlib/releases/download/%{version}/%{name}-%{version}.tar.gz
Source2:        https://github.com/Hamlib/Hamlib/releases/download/%{version}/%{name}-%{version}.tar.gz.asc
# taken from debian
Source3:        %{name}.keyring
Patch0:         hamlib-3.0-perl_install.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  perl
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  readline-devel
BuildRequires:  swig
BuildRequires:  pkgconfig(gdlib)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(tcl)

%description
The Ham Radio Control Libraries (Hamlib) provide a programming
interface for controlling radios and other shack hardware.
It is a software layer, not a complete user application.

%package devel
Summary:        Development files for hamlib, a set of radio control libraries
Group:          Development/Libraries/Other
Requires:       libhamlib%{sover} = %{version}
Requires:       libhamlib++%{sover} = %{version}

%description devel
Hamlib provide a programming interface for controlling radios and
other shack hardware.

%package -n libhamlib++%{sover}
Summary:        C++ interface of the Ham Radio Control Libraries
Group:          System/Libraries

%description -n libhamlib++%{sover}
Hamlib provides a programming interface for controlling radios and
other shack hardware. It is a software layer, not a complete user
application.

%package -n libhamlib%{sover}
Summary:        C interface of the Ham Radio Control Libraries
Group:          System/Libraries

%description -n libhamlib%{sover}
Hamlib provides a programming interface for controlling radios and
other shack hardware. It is a software layer, not a complete user
application.

%package -n lua-Hamliblua
Summary:        LUA bindings for Hamlib
Group:          Development/Libraries/Other

%description -n lua-Hamliblua
Hamlib provide a programming interface for controlling radios and
other shack hardware.

%package -n python3-Hamlib
Summary:        Python 3 bindings for Hamlib
Group:          Development/Libraries/Python

%description -n python3-Hamlib
Hamlib provide a programming interface for controlling radios and
other shack hardware.

%package -n tcl-Hamlib
Summary:        Tcl bindings for Hamlib
Group:          Development/Languages/Tcl
%requires_ge    tcl

%description -n tcl-Hamlib
Hamlib provide a programming interface for controlling radios and
other shack hardware.

%package -n perl-Hamlib
Summary:        Perl bindings for Hamlib
Group:          Development/Languages/Perl
%requires_ge    perl-base

%description -n perl-Hamlib
Hamlib provide a programming interface for controlling radios and
other shack hardware.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure \
  --with-perl-binding \
  --with-tcl-binding \
  --with-lua-binding \
  --with-python-binding PYTHON_VERSION=%{py3_ver} \
  --with-xml-support
%make_build

%install
%make_install
find %{buildroot} -type f \( -name '*.a' -o -name '*.la' \) -delete -print

rm %{buildroot}%{perl_vendorarch}/auto/Hamlib/.packlist

mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}/%{_datadir}/doc/%{name} %{buildroot}%{_docdir}

%fdupes %{buildroot}%{python_sitearch}

%check
%make_build check

%ldconfig_scriptlets -n libhamlib%{sover}
%ldconfig_scriptlets -n libhamlib++%{sover}

%files
%license LICENSE
%doc AUTHORS NEWS
%{_bindir}/rigctl
%{_bindir}/rigctld
%{_bindir}/rigctlsync
%{_bindir}/rigctltcp
%{_bindir}/rigfreqwalk
%{_bindir}/rigmem
%{_bindir}/rigsmtr
%{_bindir}/rigswr
%{_bindir}/rigtestmcast
%{_bindir}/rigtestmcastrx
%{_bindir}/rotctl
%{_bindir}/rotctld
%{_bindir}/ampctl
%{_bindir}/ampctld
%{_bindir}/rigctlcom
%{_bindir}/rigtestlibusb
%{_mandir}/man1/rigctl.1%{?ext_man}
%{_mandir}/man1/rigctld.1%{?ext_man}
%{_mandir}/man1/rigctlsync.1%{?ext_man}
%{_mandir}/man1/rigmem.1%{?ext_man}
%{_mandir}/man1/rigsmtr.1%{?ext_man}
%{_mandir}/man1/rigswr.1%{?ext_man}
%{_mandir}/man1/rotctl.1%{?ext_man}
%{_mandir}/man1/rotctld.1%{?ext_man}
%{_mandir}/man1/ampctl.1%{?ext_man}
%{_mandir}/man1/ampctld.1%{?ext_man}
%{_mandir}/man1/rigctlcom.1%{?ext_man}
%{_mandir}/man7/hamlib-primer.7%{?ext_man}
%{_mandir}/man7/hamlib-utilities.7%{?ext_man}
%{_mandir}/man7/hamlib.7%{?ext_man}
%{_docdir}/hamlib
%exclude %{_docdir}/hamlib/COPYING*
%exclude %{_docdir}/hamlib/LICENSE

%files devel
%license COPYING COPYING.LIB
%dir %{_includedir}/hamlib
%{_includedir}/hamlib/*.h
%{_datadir}/aclocal/hamlib.m4
%{_libdir}/pkgconfig/hamlib.pc
%{_libdir}/libhamlib.so
%{_libdir}/libhamlib++.so

%files -n libhamlib%{sover}
%license COPYING COPYING.LIB
%{_libdir}/libhamlib.so.%{sover}*

%files -n libhamlib++%{sover}
%license COPYING COPYING.LIB
%{_libdir}/libhamlib++.so.%{sover}*

%files -n lua-Hamliblua
%license COPYING COPYING.LIB
%{_libdir}/lua

%files -n python3-Hamlib
%license COPYING COPYING.LIB
%{python3_sitearch}/Hamlib.*
%{python3_sitearch}/_Hamlib.*
%{python3_sitearch}/__pycache__/Hamlib.cpython*.pyc

%files -n tcl-Hamlib
%license COPYING COPYING.LIB
%dir %{_libdir}/tcl*/
%dir %{_libdir}/tcl*/Hamlib
%{_libdir}/tcl*/Hamlib/*

%files -n perl-Hamlib
%license COPYING COPYING.LIB
%{perl_vendorarch}/*

%changelog
* Mon Feb 10 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 4.6.2:
  * Add missing levels for IC746/PRO RIG_LEVEL_RFPOWER_METER,
    RIG_LEVEL_RFPOWER_METER_WATTS,RIG_LEVEL_SWR,RIG_LEVEL_ALC
  * Fix IC905 for gpredict
  * Fix potential segfault on QMX
  * Fix pmr171
* Wed Jan 22 2025 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.6.1:
  * Fix C++ builds failing on rig_list_foreach function
  * Fix IC9100 rigctld startup to end up on VFOA
  * Fix grig build by removing sys/socket.h -- apparently not needed
  * Add new QMX entry to fix incompability with QDX
  * Fix IC746/PROT to not use data byte
  * FLRig to add DATA-U DATA-L modes
  * Fix TS570 RIG_LEVEL_STRENGTH with cal table
  * Remove get_powerstat from IC785X -- not supported
  * Fix SDRConsole by removing lots of things it does not have
- drop patches:
  * 0001-Change-rig_list_foreach-back-to-using-const-argument.patch
  * 0002-Fix-testrigopen.c-rig_list_foreach.patch
  * 0003-Fix-listrigs.s-rig_list_foreach.patch
  * 0004-Fix-rig_list_foreach-in-hamlibmodels.c.patch
  * 0005-Fix-rig_list_foreach-in-testmW2power.c.patch
* Sat Jan 11 2025 Andreas Stieger <andreas.stieger@gmx.de>
- add patches from upstream fixing Tucnak build:
  * 0001-Change-rig_list_foreach-back-to-using-const-argument.patch
  * 0002-Fix-testrigopen.c-rig_list_foreach.patch
  * 0003-Fix-listrigs.s-rig_list_foreach.patch
  * 0004-Fix-rig_list_foreach-in-hamlibmodels.c.patch
  * 0005-Fix-rig_list_foreach-in-testmW2power.c.patch
* Sat Dec 28 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.6 (2024-12-24)
  * send_raw can now take hex digits as colon-separated -- e.g.
    send _raw icom xfe:xfe:x94:xe0:03:xfd
  * Add IC7760
  * IC7300 Mode filter can now be set by # (i.e. 1,2,3)
  * Fixed AF6SA WRC rotor controller
  * Added Rhode&Schwarz XK852
  * Added Xiegu X6200
  * Added Commradio CTX-10
  * Added Guoehe PMR-171
  * Added csntechnoligies.net S.A.T Satellite rotor control
  * Added PSTRotator control
  * Added Flex SmartSDR slices A-H
  * Added Motorola Micom M2/M3
  * Added SDR Radio SDRConsole -- TS-2000 is now hardware flow
    control so need separate entry
  * Added --set-conf=filter_usb, filter_usbd, and filter_cw to
    allow Icom rigs set mode to set filter number too
  * Added macros for applications to obtain pointers to Hamlib
    structures(issues #1445, #1420, #487). Internal conversion is
    still a WIP, but use of these macros will make the final cutover
    transparent to applications.
  * Added Guohe Q900 entry
  * Unify behavior of all rigctl split commands
  * Make the set_split_* commands modify the state of the specified
    split VFO -- the current or targeted VFO do not have any effect
  * Make the set_split_* commands enable split automatically if not
    enabled
  * Make the get_split_* commands return frequency of 0 Hz, mode
    NONE and filter of 0 Hz if split is not enabled
  * Allow all split commands to avoid VFO swapping if supported by
    the rig model
  * Improve Icom backend to set/get frequency, mode and filter
    without VFO swapping if supported by the rig model
  * Improve Yaesu newcat backend split handling
  * Expose "Targetable features" (RIG_TARGETABLE_*) in dump_caps
    output to allow clients to determine which commands can be
    executed  without VFO swapping
  * Added RIG_FUNC_SYNC for FTDX101D/MP
  * Added Barrett 4100
  * Added DL2MAN (tr)uSDX -- needs refinement
  * Added Thetis entry -- derived from FlexRadio/Apache PowerSDR
  * Added VOICE/CW memory capability to many rigs -- thanks to David
    Balharrie M0DGB/G8FKH
  * Add -# --skip_init option to rigctl to skip rig initialization --
    useful for executing commands quickly
  * rig_caps is no longer constant -- this may break some 3rd party
    relying on the "const" declaration.
  * IC7610 now has IPP, DPP, and TX_INHIBIT functions set/get
  * Hamlib now starts a multicast server that sends out rig
    information. Does not receive commands yet. See README.multicast
  * rigctld has new -b/bind-all option to try all interfaces
  - - restores original behavior. This was done to fix duplicate
    rigctld instances on Windows
  * Yaesu rigs can now use send_morse to send keyer message 1-5
    or a CW message up to 50 chars (which will use memory 1)
  * rig set level METER can now take SWR,COMP,ALC,IC/ID,DB,PO,
    VDD,TEMP arguments to set which meter to display
  * reg get level displays meter number=name now
  * Added parm BANDSELECT for Yaesu rigs
    'p BANDSELECT' returns current band of VFOA
    'P BANDSELECT BAND160M' example selects the 160M band
    'P BANDSELECT ?' shows  bands available for the rig
  * Added rig_cm108_get/set_bit to API and get/set_gpio to
    rigctl(d) for GPIO1,2,3,4 access on CM108
  * Added BG2FX FX4/C/CR/L
  * Fixed IC7610 to use new 0x25 0x26 command added in latest
    firmware
  * Fix W command in rigctld to work properly -- can take
    terminating char or # of bytes to expect
  * Add rig_set_debug_filename so Python can redirect debug stream
  * Fix Yaesu LBL_NR to use proper values
  * Add IC-905
  * Add Anytone D578UVIII -- should work on any D558 model and
    perhaps others too
  * Add saebrtrack rotor
    https://sites.google.com/site/marklhammond/saebrtrack
  * Add offset_vfoa and offset_vfob applying to rig_set_freq
  * Fix K4 to put it in K40 mode when requesting ID
  * Fixes for M2 Rotors
  * Add rigctlsync utility to synchronize frequency from a rig
    to SDR# (or others)
  * Add SDR# rig for use with SDR#'s gpredict plugin -- can only
    get/set freq
  * Add Apex Shared Loop rotator -- unidirectional only so far
  * Add client_version to rigctld so client can report it's
    version for future use/compatibility/alternatives
  * Add --set-conf=tuner_control_pathname=hamlib_tuner_control
    (default). If file exists then it will be called with 0/1
    (Off/On) argument with 'U TUNER 0' or 'U TUNER 1". Default
    path is for current directory
  * Add MDS 4710/9710 rigs
  * Add FLIR PTU-D48, E46, D100, D300 rotors
  * Fix FTDX3000 rig split
  * Fix rigctld/rigctltcp information
  * Fix FT817 get/set_vfo
- remove patch hamlib-add-stdlib-header.patch (applied upstream)
* Thu Sep 26 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- add patch hamlib-add-stdlib-header.patch to fix the build for
  Tumbleweed
* Mon May 22 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- switch to upstream bootstrapped tarball
- add upstream signing key and verify source signature
- drop obsolete texinfo macros
* Sun Apr  9 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.5.5 (2023-04-05)
  * Add park to rotorez.c
  * Fix rig power on/off from rigctl cmd line and rigctld
  * Enable async mode by default to prevent WSJT-X crash on IC9700
    with transceive on
  * Fix IC7610 get_powerstat to disable it -- cannot read power status
  * Fix K3 K22 command error for remote operations
  * Fix Gemini DX1200 gemini_set_level
  * Fix async I/O to not call flush
  * Change EX startup commands for Yaesu rigs to allow
    errors...Win4Yaesu not recognizing EX commands
  * Fix jst145 set_freq and get_freq
  * Restore tcflush as some odd behavior was seen that tclush fixes
  * Fix XG3 operations
  * Separate the validation cmd in newcat.c to allow rig
    post_write_delay to be in effect
  * Increase post_write to 20ms for FT710
  * Add attenuator level control for TS890
  * Update SMeter/SWR tables for TS890
  * Add fix for TMD700
  * Improve FT-857 get_vfo response when error occurs
  * Allow FT-857 to use cached vfo on get_vfo when error
    occurs reading EEPROM
  * Fix FTDX10 FT710 set_level AF
  * Fix FT-450D detection
  * Fix VFO A/B swapping for gpredict -- hopefully better
    behavior for VFO swapping rigs. Should avoid setting RX freq
    while TX and avoid TX freq while RX
  * Fix QRP QDX PTT to new TQ command due to firmware changes
  * Remove EX103 check for FTDX5000
  * Fix K3/K3S VFOB setting of mode/width
  * Fix AGC level display in rigctld
  * Change FTDX10 to no serial handshake
  * Add TS2000 to has_ps exception
  * Add FT991 to 60M exception
  * Fix get_powerstat bad call in rigctl_parse.c
  * Really fix CM108 ptt_bitnum usage
  * Fix Elecraft power2mW precision/accuracy
  * Fix power on/off/on for Icom rigs with rigctld power_on=0
* Thu Jan 12 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.5.4 (2023-01-10)
  * Fix CM108 ptt setting for non-default usage
  * Fix power on/off for Icom rigs with rigctld power_on=0
  * Fix get_powerstat status return for non-PS kenwood rigs
  * Fix FT-710, FTDX10, FTDX101D/MP usage on 60M
  * Fix timing on NRD-535D
  * Fix AGC levels with rigctld
  * Fix FTDX3000 EX039 error
  * Fix Elecraft power2mW operation
  * Fix rig_power2mW so it checks all ranges
  * Allow rigctld to start with autopower_on=0 to avoid startup
    timeouts when rig is powered off
  * Fix dummy device to work with grig by disallowing empty "u" call
  * Fix ID5100 and promote to stable and hopefully ID4100 too
  * Remove get_powerstat from Icom ID-5100,ID-4100,ID-31,ID-51 and
    fix get/set freq in all
* Sun Jan  1 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.5.3 (2022-12-31)
  * Fix serial.c for hardware flow control on Linux and MacOSy
  * Add QRPLabs QCX/QDX rig -- not quite a TS480
  * Fix QRP QRDX firmware bugs in IF message so PTT works now
  * FTDX5000 will now remember startup front/read settings and restore it
  * Fix FTDX5000 write_delay with microham
* Tue Dec 27 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.5.2 (2022-12-23)
  * Fix PowerSDR ability to do commands while powered off
  * Fix TX-500 operations
  * Fix FTDX5000 to return to MIC input on closing
  * Fix rig.c calling rig_get_mode when backend does not have get_mode
  * Fix kenwood_ts890_get_level
  * Add Prosistel D elevation CBOX az to fix problem with azimuth
    control
  * Fix FT736R gpredict usage by adding cached get_freq
  * Fix get_powerstat problem with Log4OM/Flex and others
  * Fix -R option to not need argument
  * Fix -R option to close rig on last rigctld client disconnect
  * Add FTDX1200 to rigs that need to ensure PTT is off before
    changing frequency
  * Add --disable-parallel configure option for mingw builds on Linux
* Fri Dec  9 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.5.1 (2022-12-08)
  * FT2000, FTDX3000/D, FT891, FT991, FT950, FTDX5000 now set CAT TOT
  to 100ms
  * Add missing NB2 setting to FT-950, FTDX-1200, FTDX-3000, FTDX-5000,
  FTDX-9000
  * Add missing meter reading to TS-890S -- thanks to Geore Baltz N3GB
  * Fix FT736 VFOB freq and mode set
  * Added send_raw to rigctl -- see rigctl man page
  * Fix AGC Level dumpcaps on most rigs
  * Fix rig_send_raw to return bytes read, fill buffer, and also work
  with fixed length response/null terminator
  * Change all Kenwood rigs to 500ms serial timeout
  * Fix dumpcaps filter printout to only show declared filters
  * Fix triggering PTT on XGComms device on Linux
  * Fix level_gran in all rigs
  * Add RIG_FUNC_TUNER to flrig.c
  * Fix FT-991 level_gran (needs to be done for lots of rigs)
  * Fix man page rigctl to show units for LEVEL items
  * Fix Flex6xxx if_len
  * Fix FLRig set_ptt
  * Fix missing KEYSPD to TS890
  * rigctl 'W' command can now use a singled char terminator like ;
  that allows for variable length responses with no timeout --
  e.g.  WFA; ;
  * New RIG_LEVEL_USB_AF to control audio gain from rig to computer
  - - to allow AGC function in software using RF and USB_AF
  * Add RIG_LEVEL_AGC_TIME to allow AGC/OFF to be set for IC-7300,
  IC-9700, IC-705
  * Add RIG_FUNC_OVF_STATUS to get overflow status for IC-7300,
  IC-9700, IC-705, and IC-R8600
* Thu Nov  3 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.5 (2022-10-30)
  * New rotator utility https://www.pianetaradio.it/blog/catrotator/
  * Add FT-710
  * Add Rohde&Schwartz EK89X receiver
  * Add Xeigu X5105
  * Add Gemini DX-1200 HF-1K Amplifiers
  * Kenwood rigs should now support AI command packets
  * Add FT-990UNI for older 990 ROMs 1.2 and earlier
  * Add FT-650
  * Add get_separator and set_separator and -S option for rigctld -- node-red applicability
  * Add GRBLTRK rotor project -- two axis rotor
  * enum meter_level_e is deprecated and will be removed in 4.6
  * Add SDRPlay SDRUno rig -- can now use Data/Pkt in WSJTX
  * Add ability to use cat_string to FLRig via the "w" and "W" commands
  * Add -B/--mapa2b to rigctlcom
    Allows rigctlcom to map set_freq on VFOA to VFOB instead
    This will allow CW Skimmer to work with some rigs (e.g. IC7300) using FM
    mode on VFOA and CW mode on VFOB and split mode transmit on VFOB.
    Clicking on CW Skimmer will change VFOB instead of VFOA to allow
    working dxpeditions where the fox is staying on frequency
  * Add password capability to rigctld via -A switch.
    rigctld -A will produce a consistent shared key for any
    specific password that can used in \password and rig_set_password
    TBD The shared key can also be placed in .hamlib_settings
  * Asynchronous rig data output handling to support transceive
    and spectrum data. Mikael, OH3BHX
  * See new set_conf option async for some Icom rigs
  * Multicast UDP packet output for asynchronous data. Mikael, OH3BHX
  * Rig state poll routine to serve commonly used data like frequency
    and mode from cache. Mikael, OH3BHX
  * deprecated hamlib_port_t at front of rig_state structure -- new
    one at end of structure
  * New rig_send_raw to send/read raw command to rig
  * New RIG_LEVEL_BAND_SELECT for Yaesu rigs
  * New rig_get_conf2 to replace rig_get_conf buffer overflow potential
  * New rot_get_conf2 to reaplce rot_get_conf buffer overflow potential
  * Added Barrett 4050 -- not functional yet
  * Added TCI 1.X -- not functional yet
  * Added TM-V71(A)
  * Added IC-F8101
  * Added JRC JST-145 and JST-245
  * Added Xiegu X108G, G90, and X6100
  * Added CODAN Envoy and NGS
  * Added Lab599 TX-500
  * Added GOMSPACE GS100
  * Deprecated: rigctl commands \set_trn (A) and \get_trn (a) as
    they never worked as intended
  * Deprecated: field rig_caps.transceive and RIG_TRN_* macros
* Mon Feb  7 2022 Martin Pluskal <mpluskal@suse.com>
- Be less strict with required interpreters for tcl and perl
  subpackages (bsc#1195260)
- Drop python2 subpackage as its not relevant to any supported
  openSUSE release
* Wed Dec  8 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Fixed source URL and duplicate license files
* Sat Dec  4 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.4
  * Icom rigs now default filter 2 when setting PKTUSB but user can
    override
  * Fix FTDX9000 meter readings
  * Add Android sensor as a rotator
  * Added rig_get_vfo to some Icom rigs that have XCHG or 0x25
    command capability
  * Added ability to build hamlib with docker
  * Added M0NKA mcHF URP rig
  * Faster serial i/o noticeable on higher baud rates
  * IC7300/9700/7800/785x set_clock/get_clock routines
    added -- no auto set yet
  * Yaesu FT1200/891/991/DX10/DX101/DX101MP set_clock/get_clock
    routines added
* Sun Sep 19 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Fixed source URL
* Fri Sep 17 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.3.1
  * Bug fix release
  - Do not do vfo_fixup on satmode rigs
  - Fix compilation of misc.c with gmtime_r replacement function
    for mingw
  - Fix python build.  For some reason casting tp vfo_t in the
    RIG_VFO_N macro broke the swig parsing
  - Append the missing information to build hamlib v4.3 for
    Android NDK
  - Change set_icom_set_mode_with_data to not change mode unless
    necessary
  - Since Icom rigs default to filter 2 if a filter is not
    selected we will do the same when turning on data mode
  - Fix segfault in kenwood_set_vfo
  - scripts: Update example in readme, since 4.0 817 is 1020
  - Make testlibusb.c compatible with libusb < 1.0.23
    Note: On systems with libusb < 1.0.23 a warning will be
    emmitted but compliation should proceed without error.
  - Update testlibusb.c warning to "may be" instead of "will be"
  - Change kenwood to only set VFOA default on 1st rig_open call
- Update to version 4.3
  * libusb-1.0.23 or greater is now required or use --without-libusb
  * Generating documentation now requires GNU source-highlighter.
  * Added IC-575
  * Less VFO swapping of newer Icom rigs -- zero swapping in WSJTX
    and JTDX
  * Dual rotator control in rotctl -R option
  * Started work on simulators -- very crude right now but usable
    to debug some things
  * Overhaul of rig split -- reverse split (VFOA=RX VFOB=TX) should
    work for rigs capable of it
    Starting VFO does not matter -- rig will end up on RX VFO
    S VFOA 1 VFOB
    S VFOB 1 VFOA
    S Main 1 Sub
    S Sub 1 Main
* Tue May 18 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 4.2
  * New rig_get_mode_bandwidths: returns token set for bandwidths
    for given mode
  * New rig_get_info: returns token set for all vfos where order
    does not matter.
  * New rig_get_vfo_info
  * FILPATHLEN has changed to HAMLIB_FILPATHLEN
  * USRP lib and gnuradio are deprecated and will be removed in 5.0
  * Added Radan rotator
  * Added Malachite SDR
  * Major rework for PRM80
  * Add twiddle_timeout and twiddle_rit --set-conf options
  * rigctld --twiddle is deprecated and will be removed in 5.0
    along with get_twiddle and set_twiddle
* Tue Mar 16 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.1
  * rigctld and rigs should be more robust for disconnect problems
  * Several fixes for Icom and Yaesu rigs
  * Nobody should need to use rig->caps or rig->state anymore
  * New rig_get_caps_int and rig_get_caps_cptr functions to replace
    using caps-> values
  * New rig_get_function to replace using caps-> function pointers
  * Fix shared library problem with WSJTX, JTDX, and JS8Call
  * New model Barrett 950
* Thu Jan  7 2021 Wang Jun <jgwang@suse.com>
- Update to version 4.0
  * Major changes in 4.0 affecting usage
  * Most rig model numbers have changed
  * RIG_LEVEL_VOX has been deprecated and replaced by RIG_LEVEL_VOXDELAY
  * rigctl 'f' command now returns VFO argument too
  * rigctl 'y' and 'Y' command now take/show antenna argument and option.
  * range_list items are undergoing changes towards a different model TBD
  * RTS/DTR PTT sharing is off by default now -- use serial_share=1
    option to enable
* Wed Apr 29 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Tumbleweed: Python backend built for python-3.8
* Sat Apr 25 2020 Martin Pluskal <mpluskal@suse.com>
- Do not build python2 bindings for Tumbleweed
- Modernise spec file
* Thu Aug 30 2018 mardnh@gmx.de
- Update to version 3.3
  * New models, R&S xk2100, TRXMAnager, Meade LX200
  * HTML manual is now generated at 'make dist' so users don't
    need GNU Info tools installed.  TNX Greg, N1DAM for the suggestion.
  * Handle longer udev generated file names up to 512 characters
  * Add debug time stamps with new '-Z' option and '--debug-time-stamps'
    options to rigctl, rotctl, rigctld, and rotctld utilities.
  * rigctld/rotctld continue working after serial or TCP device
    disappears.
  * Updates and fixes to FT-817, K3, IC-7300, AOR 3030, TM-D710,
    OMNI VII, TH-D72, Flrig, TS-590, piHPSDR, TS-2000, and netrigctl.
  * Update utility manual pages (section 1) and remove their reference
    material from the Info manual so it only needs to be update in one
    file.
  * Add new general project manual pages (section 7) and edit the Info
    manual to match.  These should not change much so keeping them in
    sync should not be too much of a burden.  The Info manual may be
    removed at some point in the future.
  * Last planned release of the present API/ABI.  Future releases will
    require recompilation and relinking by client programs using the C
    library interface (programs that only use the network daemons should
    be unaffected).
* Wed Apr  4 2018 mpluskal@suse.com
- Update dependencies
* Sun Apr  1 2018 mardnh@gmx.de
- Update to version 3.2
  * New models, IC-7850/IC-7851 in IC-785x.  Mike, W9MDB
  * Fix ft991_get_mode, Mike, W9MDB
  * New model, FT-891.  Mike, W9MDB
  * New Barrett 2050 backend, Mike, W9MDB
  * New Flrig backend, Mike, W9MDB
  * New model, IC-M710, Mike, W9MDB
  * Build instructions and test script for Python3
  * Rename autogen.sh to bootsrap and don't call configure
  * micro-ham support. Christoph, DL1YCF
  * New rotator, SPID MD-01/02 in ROT2 mode, Norvald Ryeng, LA6YKA
  * New model, Flex 6400/6600, Mike, W9MDB
  * New model, IC-7610, Mike, W9MDB
  * Add support for CM108B PTT, Max Lock
  * New model, Rohde & Schwarz XK2100, Mike, W9MDB
  * Many other bug fixes and enhancements
- Rebase patch hamlib-3.0-perl_install.patch
* Fri Jun  2 2017 mpluskal@suse.com
- Install all license files
* Thu Apr 27 2017 jengelh@inai.de
- Ensure neutrality of description. Trim duplicate inner
  descrpitions.
* Mon Apr 24 2017 mpluskal@suse.com
- Cleanup package
- Split subpackages with libraries
- Enable tcl and perl bindings:
  * add hamlib-3.0-perl_install.patch
- Run internal testsuite
* Sun Apr 16 2017 mardnh@gmx.de
- update to version 3.1 (tagged release)
- minor specfile cleanup
* Fri Apr  7 2017 dl8fcl@darc.de
- update to version 3.1_git20170406
  New model: Icom IC-R6
  Allow RIG_LEVEL_STRENGTH queries over the network link
* Sun Mar  5 2017 dl8fcl@darc.de
- update to version 3.1_git20170227
  Fix a state machine defect with repeated PTT reset calls
  Add Dorji DRA818 modules (VHF and UHF variants)
* Sun Feb 19 2017 dl8fcl@darc.de
- update to version 3.1_git20170219
  Fix some endian issues in the si570/AVR SDR back ends
  Added x108g backend
  Fix FT-891 recognition
  Breakout FT-1000D file for full support
  Fix DIG MODE for FT817-ND
  Add support for AGC Levels
* Sat Jan 28 2017 dl8fcl@darc.de
- update to version 3.1_git20170127
  Added HPSDR backend
  Fix ic785x default addr to 0x8e
  Clears potential garbage data in read buffer prior to command being sent
  Updated PiHPSDR backend defaults
  Use Windows ioctlsocket to avoid buffer overrun
  Add get and set split functions for the TS450S
  Simplify and fix defects in the FT991 back end
  Added HPSDR backend
* Sat Jan  7 2017 dl8fcl@darc.de
- update to version 3.1_git20170107
  Fix ft991_get_mode
  New models: IC-7849/IC-7851, FT-891
* Sun Dec 25 2016 dl8fcl@t-online.de
- update to version 3.1_git20161225
  Fix typos
  Corrected a few bugs and rebased from Ervin's (HA2OS) pull request.
  Added new example to Python demo script (set/get float type level)
  Added Lua binding and demo script
  Adds test for ID 907 for the Flex 6300
  python-binding and lua-binding enabled
* Sat Nov 19 2016 dl8fcl@t-online.de
- update to version 3.1_git20161119
  Move K3 DT0 before mode switch, add version info to electraft rig open,
  WSJT-X VOX rig split now works
* Tue Nov  8 2016 dl8fcl@t-online.de
- update to version 3.1_git20161106
  New Perseus model
  Fixed buffer overflow in rigctl_parse and rotctl_parse
  Changed some modules to LGPL in lieu of GPL
  Change the IC7600 & IC7800 set/get mode to versions that support DATA…
  fix set_vfo behavior of TS2000
  fix NET rigctl
* Mon Sep  5 2016 dl8fcl@t-online.de
- update to version 3.1_git20160904
  xg3: fix buffer overflow
  Fix issue with TS-570S|D open in rig_caps
  Release the serial port used for PTT when possible
* Sat Aug 27 2016 dl8fcl@t-online.de
- update to version 3.1_git20160827
  Fix an issue presenting on the Yaesu FT-450(D)
  Fix issue with TS-570S|D open in rig_caps
  Updated smeter calibration for ic7300
* Sun Jun 12 2016 dl8fcl@t-online.de
- update to version 3.1_git20160611
  implemented set_conf, get_conf and Token fast_set_commands for max
  throughput
  Yaesu Fast Set Commands (High throughput for commands)
  added send_morse and civ_version to ic7100/ic7600
  added get/set_conf for FT1200, FT2000, FT450, FT5000 and FT9000
  Fixed SCAN_STOP for all rigs and implmented it plus SCOPE for ic7300
  Changes for IC-7300 and IC-7200
* Mon May 23 2016 dl8fcl@t-online.de
- update to version 3.1_git20160521
  Do not attempt to query AI state on several Kenwood rigs
  Add some functionality to the tmd710
  Add send_morse to icom rigs
  Do not crash if expected CTCSS tones not sepcified
  Add RIG_PASSBAND_NOCHANGE as possible set_{split_,split_freq_,}mode a…
  Initial support for the IC-7300
* Mon Apr  4 2016 dl8fcl@t-online.de
- update to version 3.1_git20160402
  Added support for Icom IC-2730
  Use rig state rig port retry option rather than from capabilities
  Use a sensible port timeout value for the Kenwood TS-850
  Make sure right band is used when setting frequency on IC-910(H)
  VFO targetable get frequency operation for the Icom IC-910(h)
  Better set frequency semantics for the IC-910(h)
  Do not swap VFO unnecessarily
  Elide unnecessary CAT commands when setting split frequency and mode
  Add {get,set}_splitfrequency_mode for the IC-910(H)
  Implement rig_{set,get}_split_freq_mode() for IC-756 series.
  Initial implementation of rig_{set,get}_split_freq_mode() for FT-857.
  Implement combined split VFO frequency and mode setting.
  Fixed get_vfo for FT-757GX(II)
  Allow the ft757gx to work with WSJT-X
  Add 23cms to IC-910(H) backend
  Improve IPv6 portability and consistency
  Various Yaesu updates
  Add get_freq to FRG-100
  Favor $HOME over '~' in text
  Fix a logic error in band detection during IC-910 set frequency
  Merge branch 'ic910-set-freq' of git://git.code.sf.net/u/bsomervi/hamlib
* Sat Jan 16 2016 dl8fcl@t-online.de
- update to version 3.1_git20160115
  Fix possible frequency overflow on Kenwood and Yaesu
  Install daemon man files to man1
  New Prosistel rotor backend from IZ7CRX
  Fix missing PKTUSB mode setting code for FT-817 & FT-897
* Fri Dec 11 2015 dl8fcl@darc.de
- update to version 3.1_git20151207
  Fix FT-817/857/897 issues and add some missing functionality
  Use correct function to execute set type commands with no response
  Add a new command line option '--no-restore-ai' ('-n') to rigctl
  Allow for poor emulations of Kenwood rigs that have no ID command
  Attempt to restore AI status on exit
  Proper IPv6 and dual stack networking
* Sun Nov 22 2015 dl8fcl@t-online.de
- update to version 3.1_git20151122
  Remove unecessary delays from TS-940S backend
* Mon Nov  9 2015 dl8fcl@darc.de
- update to version 3.1_git20151109
  change command validation for Yaesu set commands
* Sun Sep 20 2015 dl8fcl@darc.de
- update to version 3.1_git20150920
  fix kenwood_set_mode for ts590s and mode CW, RTTY or AM
* Thu Sep  3 2015 dl8fcl@darc.de
- update to version 3.0_git20150903
  Add library paths for tests
* Sat Aug 22 2015 dl8fcl@darc.de
- update to version 3.0_git20150822
  New CNCTRK rotor backend
* Mon Aug 17 2015 dl8fcl@darc.de
- update to version 3.0_git20150815
  Fixes power level reporting for the Omni VII. Backend is
  promoted to STABLE status.
  Fixes S meter reporting for FT857 and FT991.
  Fixes rig split for FT991. Working now for WSJT-X rig split mode.
* Mon Jul 27 2015 dl8fcl@darc.de
- update to version 3.0_git20150727
  Allows the FT-991 to work with Fake Split in WSJT-X
* Fri Jul 17 2015 dl8fcl@darc.de
- update to version 3.0_git20150717
  Fix for Yaesu FT-991
* Fri Jul  3 2015 dl8fcl@darc.de
- update to version 3.0_git20150703
  Omni VII patch for WSJT-X
* Sat May 23 2015 dl8fcl@darc.de
- update to version 3.0_git20150523
  Omni VII set VFO_CURR correctly
* Sun Apr 26 2015 dl8fcl@darc.de
- update to version 3.0_git20150425 - beta version
  with a lot of new features and new rig backends
* Fri Nov  9 2012 dl8fcl@darc.de
- update to version 1.2.15.3
* Fri Feb  3 2012 dl8fcl@darc.de
- update to version 1.2.15
* Sun Jul 31 2011 dl8fcl@darc.de
- update to version 1.2.14
* Sun May 29 2011 dl8fcl@darc.de
- update to version 1.2.13.1
* Sun Mar 13 2011 dl8fcl@darc.de
- update to version 1.2.13
* Mon Sep  6 2010 dl8fcl@darc.de
- update to version 1.2.12
* Mon Jun  7 2010 dl8fcl@darc.de
- update to version 1.2.11
* Mon Nov  2 2009 dl8fcl@darc.de
- update to version 1.2.10
* Sun Mar  1 2009 dl8fcl@darc.de
- update to version 1.2.9
* Mon Nov  3 2008 dl8fcl@darc.de
- update to version 1.2.8
- disabled src_misc_c_strcmp.diff
* Sun Jul 22 2007 dl9pf@gmx.de
- version 1.2.6.2
* Tue Feb 20 2007 dl9pf@gmx.de
- import into buildservice
- version 1.2.6
  * Tue Jun 20 2006 Tim Fischer
- rewrite spec file for SUSE 10.1
  * Tue Sep 26 2004 Stephane Fillod
- New backends: skanti, racal, wj, tuner
- New command 'rigswr'
  * Tue Jan 20 2004 Tomi Manninen
- Fix for 1.1.5pre2
- Better use of rpm macros
- Disable all bindings
  * Tue Oct 08 2003 Joop Stakenborg
- Fix 'make rpm' again by disabling c++ bindings.
- rotclass.h and rigclass.h go into the devel package for now (FIXME)
  * Wed Jan 15 2003 Joop Stakenborg
- Fix the spec file for 1.1.4CVS
- 'make rpm' should work now
  * Thu Jun 17 2002 Stephane Fillod
- Added rotator support
- Added RPC daemon, hamlib.m4
  * Mon Jul 18 2001 Stephane Fillod
- Made initial "working" SPEC file
